@@ -2,11 +2,13 @@ use thiserror::Error;
 
 use crate::{CaptureAPIBackend, FrameFormat};
 
-/// All errors in Nokhwa.
+/// All errors in `nokhwa`.
 #[allow(clippy::module_name_repetitions)]
 #[allow(clippy::pub_enum_variant_names)]
 #[derive(Error, Debug, Clone)]
 pub enum NokhwaError {
+    #[error("Error: {0}")]
+    GeneralError(String),
     #[error("Could not open device: {0}")]
     CouldntOpenDevice(String),
     #[error("Could not query device property {property}: {error}")]
@@ -27,6 +29,8 @@ pub enum NokhwaError {
         destination: String,
         error: String,
     },
+    #[error("Could not stop stream: {0}")]
+    CouldntStopStream(String),
     #[error("This operation is not supported by backend {0}.")]
     UnsupportedOperation(CaptureAPIBackend),
     #[error("This operation is not implemented yet: {0}")]
